# Generated by Django 2.0.8 on 2018-12-31 20:21

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RequestLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('method', models.CharField(help_text='request method', max_length=10, verbose_name='method')),
                ('url', models.TextField(help_text='request url', verbose_name='url')),
                ('params', models.TextField(help_text='request params', verbose_name='parameters')),
                ('body', models.TextField(help_text='request body', verbose_name='body')),
                ('headers', models.TextField(help_text='request headers', verbose_name='headers')),
                ('response_content', models.TextField(help_text='response content', verbose_name='content')),
                ('response_headers', models.TextField(help_text='response headers', verbose_name='headers')),
                ('response_status_code', models.CharField(help_text='response status code', max_length=10, verbose_name='status code')),
                ('last_modified', models.DateTimeField(auto_now=True, help_text='last modification date', verbose_name='last modified')),
                ('created', models.DateTimeField(auto_now_add=True, help_text='creation date', verbose_name='created')),
            ],
            options={
                'verbose_name': 'Request Log',
                'verbose_name_plural': 'Request Logs',
                'db_table': 'request_log',
            },
        ),
    ]
